<?php
/**
 * Created by Agence Net Design
 *
 * @category   CherryCheckout
 * @package    CherryCheckoutCore_Charity
 * @author     Agence Net Design (http://www.agencenetdesign.com/)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */
 
class CherryCheckoutCore_Charity_Helper_Config extends CherryCheckoutCore_Charity_Helper_Data
{
    
    
    protected $_page = NULL;
    
    public function __construct(){
        parent::__construct();
        $this->getConfigData();
    }       
    
    public function getPercentageGame(){
        
        return (float)$this->getContract()->getGameOrderPercentage();
    }
    
    public function getPercentageDonation(){
        
        return (float)$this->getContract()->getCharityOrderPercentage();
    }
    public function getCharityType(){
        $pctGame = $this->getPercentageGame();
        $pctDonation = $this->getPercentageDonation();
        if($pctGame > 0 && $pctDonation > 0){
            return self::TYPE_CONTEST_DONATION;
        }
        elseif($pctDonation > 0){
            return self::TYPE_DONATION;
        }
        else{
            return self::TYPE_CONTEST;
        }
    }
    
    public function getCharityName(){
        return $this->getCharity()->getName();
    }
    public function setCurrentCheckoutPage($page){
        $this->_page = $page;
        return $this;
    }
    public function getPriceForQuote($quote){
        return $this->getPrice($quote->getGrandTotal() - $quote->getBillingAddress()->getData('cco_charity_amount') - $quote->getShippingAddress()->getData('cco_charity_amount'));
    }
    public function getPrice($amount = 0){
       if(!$this->getConfig()){
           return 0;
       }
       if(!$this->isActive()){
           return 0;
       }
        try {
            $scales = $this->getContract()->getPriceScale();
        }
        catch(Exception $e){
            $scales = NULL;
        }
        
        if(!is_array($scales)){
            return 0;
        }
        foreach($scales as $scale){
            if($scale->from <= $amount && $scale->to >= $amount){
                $this->_log('Found amount of ' . $scale->amount . ' for total of ' . $amount);
                return $scale->amount;
            }
        }
        return 0;
    }
    
    protected function getPluginHtml(){
        if($this->isActive() && $this->getConfig()){
            return $this->getConfig()->getPlugin($this->getApiLocale());
        }
        return NULL;
    }

	public function getPluginHtmlForQuote($quote){
		if(!$quote instanceof Mage_Sales_Model_Quote){
			return NULL;
		}
		if(($html = $this->getPluginHtml()) && ($price = $this->getPriceForQuote($quote))){
			$withScript = true;
			if((int)$quote->getData('cco_charity') === 1){
				preg_match('/<script(.*)<\/script>/ims',$html,$script);
				$html = $script[0];
				$withScript = false;
				//$html = '';
				//$html = mb_eregi_replace("<input [^>]+>",'<input name="cherrycheckout_cancel" class="exclusive_large cherrycheckout_submit cherrycheckout_cancel" type="submit" value="' . $this->__('Remove from cart')  . '"/>',$html);
			}
			else{
				$price = Mage::helper('core')->currency($price, true, false);
			}

			$currencySymbol = Mage::app()->getLocale()->currency($quote->getQuoteCurrencyCode())->getSymbol();

			$price = str_replace($currencySymbol, '', $price);
			$price = (int) str_replace(',00', '', $price);

			$html = str_replace('{cherryPrice}',$price,$html);
			$html = str_replace('{currency}',$currencySymbol,$html);

			if ($withScript) {
				$script = '
					<script type="text/javascript">
			            var ccoForm = new CherryCheckoutCharity(\''. Mage::getUrl('ccocharity/cart/index') .'\',\''. $this->htmlEscape(Mage::getSingleton('core/session')->getFormKey()). '\');
			            try {
			                drawPlugin();
			            }
			            catch(e){}
					</script>
				';
				$html .= $script;
			}
		}
		else{
			$html = NULL;
		}

		return $html;
	}

}
    