<?php
/**
 * Created by Agence Net Design
 *
 * @category   CherryCheckout
 * @package    CherryCheckoutCore_Charity
 * @author     Agence Net Design (http://www.agencenetdesign.com/)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

require_once('cherrycheckout.php');

class CherryCheckoutCore_Charity_Helper_Data extends Mage_Core_Helper_Abstract
{
    const PROD_API_URL          = 'https://api-v2.cherrycheckout.com/v2';
    //const DEV_API_URL           = 'https://api-v2.cherrycheckout.com/v2';
    
    const TYPE_CONTEST          = 'CHERRY_CONTEST';
    const TYPE_DONATION         = 'CHERRY_DONATION';
    const TYPE_CONTEST_DONATION = 'CHERRY_BOTH';
    
    const STATUS_PROGRESS           = 'IN_PROGRESS';
    const STATUS_VALID              = 'VALIDATED';
    const STATUS_CANCELLED          = 'CANCELLED';
    
    protected $_ccoData = array();
    protected $_active = NULL;
    protected $_cacheLifeTime = 86400;

    protected $_apiUrl = NULL;
    protected $_percentageGame = 0;
    protected $_excludeDataFromOrder = array();
    protected $_priceScales = array();
    protected $_pluginHtml = '';
    
    protected $_apiLocale = NULL;
    
    protected $_config = NULL;
    
    protected $_storeId = NULL;
    
    protected $_apiToken = NULL;
    
    protected static $registered = false;
    
    public function addAutoloader()
    {
        return;
        // this should not be necessary.  Just being done as a check
        if (self::$registered) {
            return;
        }
        spl_autoload_register(array($this, 'autoload'), false, true);
        self::$registered = true;
    }
    
    
    public function autoload($class)
    {
        $classFile = str_replace('\\', '/', $class) . '.php';
        // Only include a namespaced class.  This should leave the regular Magento autoloader alone 
        if (strpos($classFile,'CherryCheckout') !== false && strpos($classFile, '/') !== false) {
            include_once $classFile;
        }
    }
    
    public function __construct(){
        $this->_storeId = Mage::app()->getStore()->getStoreId();
    }    
    
    public function getApiToken(){
        if($this->_apiToken === NULL){
            $publicKey = $this->getClientId();
            $privateKey = $this->getSecretKey();
            
            // Generate a timestamp
            $timestamp = time();
            
            // 1. Concatenate publicKey with timestamp
            $concatenation = $publicKey.$timestamp;
            
            // 2. HMAC-256 the concatenation, with our privateKey as encryption key
            $hmac = hash_hmac('sha256', $concatenation, $privateKey);
            
            // 3. Base 64 the result
            $base64 = base64_encode($hmac);
            
            $this->_apiToken = $base64;
        }
        return $this->_apiToken;
    }
    public function isActive(){
        if($this->_active === NULL){
            $this->_active = Mage::getStoreConfig('cco_charity/settings/active',$this->_storeId) && $this->getSecretKey() && $this->getClientId();
        }
        return $this->_active;
    }
    
    /*public function getActivatedPages(){
        return explode(",",Mage::getStoreConfig('cco_charity/pages/active'));
    }
    public function getSupportedPages(){
        return array('checkout_cart_index'=>'Checkout Cart','checkout_onepage_progress'=>'One Page Progress','checkout_onepage_index_payment' => 'One Page Payment');
    }*/
    protected function getDevMode(){
        return Mage::getStoreConfig('cco_charity/settings/dev_mode',$this->_storeId);
    }

    protected function isLogEnabled(){
        return Mage::getStoreConfig('cco_charity/settings/enable_log',$this->_storeId);
    }
    
    protected function isLogApiEnabled(){
        return Mage::getStoreConfig('cco_charity/settings/enable_log_api',$this->_storeId);
    }
    
    protected function getApiUrl(){
        if($this->_apiUrl === NULL){
            $this->_apiUrl = Mage::getStoreConfig("cco_charity/settings/api_url");
            if(!$this->_apiUrl){
                $this->_apiUrl = self::PROD_API_URL;
            }
        }
        return $this->_apiUrl;
        //return $this->getDevMode() ? self::DEV_API_URL : self::PROD_API_URL;
        
    }
    protected function getSecretKey(){
        return Mage::getStoreConfig('cco_charity/settings/secret_key',$this->_storeId);
    }
    
    protected function getClientId(){
        return Mage::getStoreConfig('cco_charity/settings/client_id',$this->_storeId);
    }
    
    public function getSupportedLocales(){
        return array('fr_FR','en_GB','de_DE');
    }
    
    public function getCcoCharityStatus($status = NULL){
        if(!$status){
            return NULL;
        }
        //$progress       = explode(",",Mage::getStoreConfig('cco_charity/orders/progress_status',$this->_storeId));
        $valid          = explode(",",Mage::getStoreConfig('cco_charity/orders/valid_status',$this->_storeId));
        $cancelled      = explode(",",Mage::getStoreConfig('cco_charity/orders/cancel_status',$this->_storeId));
        /*if(in_array($status,$progress)){
            return self::STATUS_PROGRESS;
        }
        else*/
        if(in_array($status,$valid)){
            return self::STATUS_VALID;
        }
        elseif(in_array($status,$cancelled)){
            return self::STATUS_CANCELLED;
        }
        return NULL;
    }
    
    public function getStatusForApi($status = NULL){
        switch($status){
            case self::STATUS_VALID :       return 'validated';
                                            break;
            case self::STATUS_CANCELLED :   return 'canceled';
                                            break;
        }
        return NULL;
    }
    protected function getCacheId(){
        $parts = array('CherryCheckoutCore_Charity', (int)$this->_storeId, $this->getApiLocale(),$this->getApiUrl(),$this->getClientId());
        
        $key = implode('|', $parts);
        $key = sha1($key);
        return $key;
        
    }
    
    protected function getCacheLifeTime(){
        return $this->_cacheLifeTime;
    }
    
    public function _log($data){
        if($this->isLogEnabled()){
            Mage::log($data, null, 'cco_charity.log',TRUE);
        }
        return $this;
    }
    
    public function _logApi($data){
        if($this->isLogApiEnabled()){
            Mage::log($data, null, 'cco_charity_api.log',TRUE);
        }
        return $this;
    }
    
    public function getApiLocale(){
        if($this->_apiLocale === NULL){
            if(!$this->_apiLocale = Mage::getStoreConfig('cco_charity/settings/locale',$this->_storeId)){
                $this->_apiLocale = Mage::app()->getLocale()->getLocaleCode();
            }
            if(!in_array($this->_apiLocale,$this->getSupportedLocales())){
                $this->_apiLocale = 'en_GB';
            }
            $parts = explode("_",$this->_apiLocale);
            $this->_apiLocale = array_shift($parts);
        }
        return $this->_apiLocale;
    }
    
    
    public function getConfig(){
       
        return $this->getConfigData();
    }
    public function getConfigData(){
        $cacheId = $this->getCacheId();
        
        //$this->addAutoloader();
        if(!isset($this->_ccoData[$cacheId])){
            
            if($this->isActive()){
                
                if(FALSE && ($this->getCacheLifeTime() > 0) && ($cachedData = $this->_loadCache($cacheId))){
                    $this->_ccoData[$cacheId] = unserialize($cachedData);
                    $this->_config = $this->_ccoData[$cacheId];
                    $this->_log('Loading data from Cache for store ' . $this->_storeId);
                }
                else{
                    try {
                        
                        
                        $locale = $this->getApiLocale();
                        $this->_log('Getting Data from API for locale ' . $locale);
                        
                        $client = new CherryCheckout\Api($this->getApiUrl(),$this->getClientId(),$this->getSecretKey());
                        $this->_ccoData[$cacheId] = $client->getMe();
                        $this->_config = $this->_ccoData[$cacheId];
                        return $this->_config;
                        if($this->getCacheLifeTime() > 0){
                            $this->_saveCache(serialize($this->_ccoData[$cacheId]),$cacheId,array(),$this->getCacheLifeTime());
                            $this->_log('Storing data to Cache for store ' . $this->_storeId);
                        }
                        
                        
                    }
                    catch(Exception $e){
                        
                        $this->_ccoData[$cacheId] = NULL;
                        $this->_active = FALSE;
                        $this->_log('Exception ' . $e->getMessage());
                        
                        
                    }
                }
                            
            }
            else{
                $this->_ccoData[$cacheId] = NULL;
                $this->_active = FALSE;
            }
        }
        
        return $this->_ccoData[$cacheId];
    }
    
    protected function _initDataFromConfig(){
        $this->_config = new Varien_Object;
        $cacheId = $this->getCacheId();
        if(!$this->_ccoData[$cacheId]){
            $this->_active = FALSE;
        }
        else{
            $this->_config = $this->_ccoData[$cacheId];
            
        }
        
    }
    
    public function getLabelType($type = NULL){
        if(!$type){
            return NULL;
        }
        switch($type){
            case self::TYPE_CONTEST             :   return 'Contest - Cherry Checkout';
                                                    break; 
            case self::TYPE_DONATION            :   return 'Donation - Cherry Checkout';
                                                    break;  
            case self::TYPE_CONTEST_DONATION    :   return 'Donation and contest - Cherry Checkout';
                                                    break;   
        }
        return NULL;
    }
    
    public function getContract(){
        if($this->getConfig() && $this->getConfig()->getContract()){
            return $this->getConfig()->getContract();
        }
        return new Varien_Object();
    }
    public function getCharity(){
        if($this->getConfig() && $this->getConfig()->getCharity()){
            return $this->getConfig()->getCharity();
        }
        return new Varien_Object();
    }
}
