<?php
/**
 * Created by Agence Net Design
 *
 * @category   CherryCheckout
 * @package    CherryCheckoutCore_Charity
 * @author     Agence Net Design (http://www.agencenetdesign.com/)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */


class CherryCheckoutCore_Charity_Helper_Order extends CherryCheckoutCore_Charity_Helper_Config
{
    public function __construct(){
    }   

    public function load($storeId){
        $this->_storeId = $storeId;
        $this->getConfigData();

    }

    public function getOrderCustomerId($order){
        if($order instanceof Mage_Sales_Model_Order){
            if($order->getData('customer_id')){
                return $order->getData('customer_id');
            }
            else{
                return 'GUEST-' . $order->getData('increment_id');
            }
        }
        return NULL;

    }

    public function getQtyFromOrder($order){
        $total = 0;
        return (int)$order->getData('total_qty_ordered');

    }
    
    public function getSendAddressInformationToCherryCheckout($storeId = NULL){
        return Mage::getStoreConfig('cco_charity/orders/send_full_customer_address',$storeId);
        return TRUE;
    }
    public function getDataOrderForApi($_order,$cco_order){
        $order = NULL;
        
        
        
        if($cco_order && ($_order instanceof Mage_Sales_Model_Order)){
            if($status = $this->getStatusForApi($cco_order->getData('cco_status'))){
                $customer = new CherryCheckout\Customer();
                $customer->setFirstname($_order->getData('customer_firstname'))
                            ->setLastname($_order->getData('customer_lastname'))
                            ->setEmail($_order->getData('customer_email'));
                if($this->getSendAddressInformationToCherryCheckout($_order->getStoreId())){
                    $customer->setAddress($_order->getBillingAddress()->getStreet(-1))
                                ->setZipCode($_order->getBillingAddress()->getPostcode())
                                ->setCity($_order->getBillingAddress()->getCity())
                                ->setCountry($_order->getBillingAddress()->getCountryId());
                }
                // Then, create an order object
                $order = new CherryCheckout\Order();
                $order
                    ->setOrderPrice($_order->getGrandTotal() - $_order->getData('cco_charity_amount'))
                    ->setCherryPrice($_order->getData('cco_charity_amount'))
                    ->setTrackId(str_replace(' ', '-', $_order->getIncrementId()))
                    ->setCurrency($_order->getData('order_currency_code'))
                    ->setCustomer($customer)
                    ->setStatus($status);
            }
                
        }
        
        return $order;
    }

    public function getDataFromOrder($order){

        $datas = NULL;
        if($order instanceof Mage_Sales_Model_Order){
            $datas = array();
            $datas['ccoNo'] = $order->getData('cco_charity_type');
            $datas['orderReference'] = str_replace(' ', '-', $order->getIncrementId());
            $datas['orderTotal'] = $order->getGrandTotal();
            $datas['cherryPrice'] = $order->getData('cco_charity_amount');
            $datas['orderQty']  = $this->getQtyFromOrder($order);
            $datas['language'] = $this->getApiLocale();
            $datas['customerId'] =  str_replace(' ', '-', $this->getOrderCustomerId($order));
            $datas['customerFirstname'] = $order->getData('customer_firstname');
            $datas['customerLastname'] = $order->getData('customer_lastname');
            $datas['customerGender'] = $order->getData('customer_gender');
            $datas['customerEmail'] = $order->getData('customer_email');
        }
        return $datas;

    }

    

    public function queueOrderToApi($order, $status){
        if($order instanceof Mage_Sales_Model_Order){
            
            $ccoOrder = Mage::getModel('cco_charity/order');
            $ccoOrder->setData(
                array(
                    'order_id'=>$order->getId(),
                    'updated_at' => NULL,
                    'cco_status'=>$status,
                )
            )->save();
        }
    }



    public function sendOrderToApi($order, $cco_order){

        //$browser = new Buzz\Browser();
        /*$client = new CherryClient($this->getApiUrl(),$this->getClientId(),$this->getSecretKey());
        $browser->setClient(new Buzz\Client\FileGetContents());
        $client->setBuzz($browser);
        $client->ignoreFields = array_merge($client->ignoreFields, $this->_config->getData('excludeDataFromOrder'));*/
        
        if($apiOrder = $this->getDataOrderForApi($order,$cco_order)){
            $this->_logApi(serialize($apiOrder));
            if(!$order->getData('cco_charity_sent')){
                try {
                    $client = new CherryCheckout\Api($this->getApiUrl(),$this->getClientId(),$this->getSecretKey());
                    $client->createOrder($apiOrder);
                    $cherryOrder = Mage::getModel('cco_charity/order')->load($cco_order->getId());
                    $cherryOrder->setUpdatedAt(Varien_Date::formatDate(TRUE));
                    $cherryOrder->setCcoOrder($order->getId());
                    $cherryOrder->save();
                    $order->setData('cco_charity_sent',1)->save();
                    $messageApi = 'new order sent';
                }
                
               
                catch(CherryCheckout\Exceptions\TrackIdAlreadyExistsException $ex) {
                    $messageApi =  "Error, this track id already exists.";
                }
                catch(CherryCheckout\Exceptions\NoCharityAvailableException $ex) {
                    $messageApi =  "Error, no charity available.";
                }
                catch(CherryCheckout\Exceptions\CustomerNotSetException $ex) {
                    $messageApi =  "Error, customer was missing.";
                }
                catch(CherryCheckout\Exceptions\CustomerEmailMissingException $ex) {
                    $messageApi =  "Error, customer e-mail was missing.";
                }
                catch(Exception $ex) {
                    $messageApi =  "Unknown error: " . $ex->getMessage();
                }
                $this->_logApi($order->getId() . ' - ' . $order->getIncrementId(). ' : ' . $messageApi);
               
            }
            else{
                try {
                    $client = new CherryCheckout\Api($this->getApiUrl(),$this->getClientId(),$this->getSecretKey());
                    $client->updateOrder($apiOrder);
                    $cherryOrder = Mage::getModel('cco_charity/order')->load($cco_order->getId());
                    $cherryOrder->setUpdatedAt(Varien_Date::formatDate(TRUE));
                    $cherryOrder->save();
                    $messageApi = 'order updated to new status ' . $ccoOrder['status'];
                    
                }
                catch(CherryCheckout\Exceptions\TrackIdMissingException $ex) {
                     $messageApi =  "Error, the track id was not set.";
                }
                catch(CherryCheckout\Exceptions\OrderNotFoundException $ex) {
                    $messageApi =  "Error, order was not found with that track id.";
                }
                catch(\Exception $ex) {
                    $messageApi = "Unknown error: " . $ex->getMessage();
                }
                $this->_logApi($order->getId() . ' - ' . $order->getIncrementId(). ' :  ' . $messageApi);
            }
        }
    }
}

    