<?php

/**
 * Created by Agence Net Design
 *
 * @category   CherryCheckout
 * @package    CherryCheckoutCore_Charity
 * @author     Agence Net Design (http://www.agencenetdesign.com/)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

class CherryCheckoutCore_Charity_Model_Observer
{
    /**
     * Set fee amount invoiced to the order
     *
     * @param Varien_Event_Observer $observer
     * @return CherryCheckoutCore_Charity_Model_Observer
     */

    public function invoiceSaveAfter(Varien_Event_Observer $observer)
    {
        $invoice = $observer->getEvent()->getInvoice();
        $helper = Mage::helper('cco_charity/config');
        $helper->_log("Invoice ID " . $invoice->getId() . " / CherryCheckout Charity amount for invoice invoice  : " . $invoice->getBaseCcoCharityAmount());
        if ($invoice->getBaseCcoCharityAmount()) {
            $order = $invoice->getOrder();
            $order->setCcoCharityAmountInvoiced($order->getCcoCharityAmountInvoiced() + $invoice->getCcoCharityAmount());
            $order->setBaseCcoCharityAmountInvoiced($order->getBaseCcoCharityAmountInvoiced() + $invoice->getBaseCcoCharityAmount());
        }
        return $this;
    }



    /**
     * Set fee amount refunded to the order
     *
     * @param Varien_Event_Observer $observer
     * @return CherryCheckoutCore_Charity_Model_Observer
     */
    public function creditmemoSaveAfter(Varien_Event_Observer $observer)
    {
        $creditmemo = $observer->getEvent()->getCreditmemo();
        if ($creditmemo->getCcoCharityAmount()) {
            $order = $creditmemo->getOrder();
            $order->setCcoCharityAmountRefunded($order->getCcoCharityAmountRefunded() + $creditmemo->getCcoCharityAmount());
            $order->setBaseCcoCharityAmountRefunded($order->getBaseCcoCharityAmountRefunded() + $creditmemo->getBaseCcoCharityAmount());
        }
        return $this;
    }

    /**
     * Update PayPal Total
     *
     * @param Varien_Event_Observer $observer
     * @return CherryCheckoutCore_Charity_Model_Observer
     */

    public function updatePaypalTotal(Varien_Event_Observer $observer)

    {
        $cart = $observer->getEvent()->getPaypalCart();
        if($cart->getSalesEntity() instanceof Mage_Sales_Model_Order){
            //$cart->updateTotal(Mage_Paypal_Model_Cart::TOTAL_SUBTOTAL, $cart->getSalesEntity()->getCcoCharityAmount());
            if($cart->getSalesEntity()->getCcoCharityAmount() > 0){
                $cart->addItem('Cherry Checkout',1,$cart->getSalesEntity()->getCcoCharityAmount(),'cco_charity');
                
            }
            
        }
        elseif($cart->getSalesEntity() instanceof Mage_Sales_Model_Quote){
            $totals = $cart->getSalesEntity()->getTotals();
            if(isset($totals['cco_charity']) && $totals['cco_charity']->getValue() > 0){
                //$cart->updateTotal(Mage_Paypal_Model_Cart::TOTAL_SUBTOTAL, $totals['cco_charity']->getValue());
                $cart->addItem($totals['cco_charity']->getTitle(),1,$totals['cco_charity']->getValue(),'cco_charity');
            }
        
        }
        //$cart->updateTotal(Mage_Paypal_Model_Cart::TOTAL_SUBTOTAL, $cart->getSalesEntity()->getCcoCharityAmount());
        return $this;

    }

    

    

    public function switchCharityOnQuote(Varien_Event_Observer $observer){
         $controllerAction =   $observer->getEvent()->getControllerAction();
         $request = $controllerAction->getRequest();
         $helper = Mage::helper('cco_charity/config');
         $quote = Mage::getSingleton('checkout/session')->getQuote();
         if($cco_input = $request->getParam('cherrycheckout_submit',NULL)){
             if($helper->isActive()){
                 $quote->setData('cco_charity',1);
                 $quote->save();
                 $helper->_log("Quote ID " . $quote->getId() . " / CherryCheckout Charity after : " . $quote->getData('cco_charity'));
             }
             else{
                $quote->setData('cco_charity',0);
                $quote->save();
                $helper->_log("Quote ID " . $quote->getId() . " / CherryCheckout Charity after : " . $quote->getData('cco_charity'));
             }
         }
         elseif($cco_input = $request->getParam('cherrycheckout_cancel',NULL)){
            $quote->setData('cco_charity',0);
            $quote->save();
            $helper->_log("Quote ID " . $quote->getId() . " / CherryCheckout Charity after : " . $quote->getData('cco_charity'));
         }
    }


    public function salesOrderChangeStatus(Varien_Event_Observer $observer){
           $order = $observer->getEvent()->getOrder();
           $helper = Mage::helper('cco_charity/config');
           $helper->_log("salesOrderChangeStatus Order ID " . $order->getId() . " / CherryCheckout Charity amount for order  : " . $order->getData('cco_charity_type'));
           if($order->getData('cco_charity_type')){ //&& $order->dataHasChangedFor('status'))
               $oldStatus = $order->getOrigData('status');
               $newStatus = $order->getData('status');
               $_helper = Mage::helper('cco_charity/order');
               $_helper->load($order->getStoreId());
               $ccoNewStatus = $_helper->getCcoCharityStatus($newStatus);
               $ccoOldStatus = $_helper->getCcoCharityStatus($oldStatus);
               $helper->_log("salesOrderChangeStatus Order ID " . $order->getId() . " / Old status : " . $ccoOldStatus . "/ New status  : " . $ccoNewStatus);
               if($ccoNewStatus && ($ccoNewStatus != $ccoOldStatus)){
                   $_helper->queueOrderToApi($order,$ccoNewStatus);
               }
           }
    }

    public function salesQuoteMergeAfter(Varien_Event_Observer $observer){
           $quote   = $observer->getEvent()->getQuote();
           $source  = $observer->getEvent()->getSource();  
           $quote->setData('cco_charity',$source->getData('cco_charity'));
           $quote->setData('cco_charity_amount_value',$source->getData('cco_charity_amount_value'));
           $quote->setData('cco_charity_type',$source->getData('cco_charity_type'));
           $quote->setData('cco_charity_name',$source->getData('cco_charity_name'));
    }
    
    
    public function changeLayoutEvent(Varien_Event_Observer $observer){
        $action = $observer->getEvent()->getAction();
        if ($action instanceof Mage_Checkout_CartController && $action->getRequest()->getRequestedActionName() == 'index') {
            $blockPosition = Mage::getStoreConfig('cco_charity/frontend/block');
            $handle = NULL;
            switch($blockPosition){
                case 'shopping.cart.table.after'    :   $handle = 'cco_charity_checkout_cart_table_after';
                                                        break;
                case 'checkout.cart.extra'          :   $handle = 'cco_charity_checkout_cart_extra';
                                                        break;
                case 'checkout.cart.form.before' :      $handle = 'cco_carity_checkout_cart_form_before';
                                                        break;
            }
           
            if($handle){
                if(Mage::getStoreConfig('cco_charity/frontend/create_extra_block')){
                    $observer->getEvent()->getLayout()->getUpdate()
                        ->addHandle('cco_carity_checkout_create_cart_extra');
                    
                }
                if(Mage::getStoreConfig('cco_charity/frontend/use_custom_cart_template')){
                    $observer->getEvent()->getLayout()->getUpdate()
                        ->addHandle('cco_carity_checkout_use_custom_cart_template');
                    
                }
                $observer->getEvent()->getLayout()->getUpdate()
                    ->addHandle($handle);
            }
             
        }   
    }

    /*public function setCustomTemplateFile(Varien_Event_Observer $observer){
        if(Mage::getStoreConfig('cco_charity/frontend/use_custom_cart_template')){
                    $observer->getEvent()->getLayout()->getUpdate()
                        ->addHandle('cco_carity_checkout_use_custom_cart_template');
                    
                }
    }*/
    
}