<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magento.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade Magento to newer
 * versions in the future. If you wish to customize Magento for your
 * needs please refer to http://www.magento.com for more information.
 *
 * @category    Mage
 * @package     Mage_Reports
 * @copyright  Copyright (c) 2006-2016 X.commerce, Inc. and affiliates (http://www.magento.com)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */


/**
 * Customers by orders Report collection
 *
 * @category    Mage
 * @package     Mage_Reports
 * @author      Magento Core Team <core@magentocommerce.com>
 */
class CherryCheckoutCore_Charity_Model_Resource_Report_Customer_Orders_Collection extends Mage_Reports_Model_Resource_Customer_Orders_Collection
{
    
    
    
    
    /**
     * Join fields
     *
     * @param string $from
     * @param string $to
     * @return Mage_Reports_Model_Resource_Customer_Orders_Collection
     */
    protected function _joinFields($from = '', $to = '')
    {
        $this->joinCustomerName()
            ->groupByCustomer()
            ->addOrdersCount()
            ->addAttributeToFilter('created_at', array('from' => $from, 'to' => $to, 'datetime' => true));
        $this->addFieldToFilter('cco_charity_type',array('notnull' => TRUE));   
        $this->addFieldToFilter('cco_charity_type',array('neq' => '' ));
        $expression = 'cco_charity_amount';
        $this->getSelect()->columns(array(
            'cco_amount' => new Zend_Db_Expr(sprintf('SUM(%s)', $expression))
        ));
       
        return $this;
    }

    /**
     * Add summary average totals
     *
     * @param int $storeId
     * @return Mage_Reports_Model_Resource_Order_Collection
     */
    public function addSumAvgTotals($storeId = 0)
    {
        $adapter = $this->getConnection();
        
        /**
         * calculate average and total amount
         */
        $expr = ($storeId == 0)
            ? "(main_table.grand_total) * main_table.base_to_global_rate"
            : "main_table.grand_total";

        $this->getSelect()
            ->columns(array('orders_avg_amount' => "AVG({$expr})"))
            ->columns(array('orders_sum_amount' => "SUM({$expr})"));
        
        return $this;
    }

    
}
