<?php
/**
 * Created by Agence Net Design
 *
 * @category   CherryCheckout
 * @package    CherryCheckoutCore_Charity
 * @author     Agence Net Design (http://www.agencenetdesign.com/)
 * @license    http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

class CherryCheckoutCore_Charity_Model_Sales_Quote_Address_Total_Fee extends Mage_Sales_Model_Quote_Address_Total_Abstract
{

    protected $_code = 'cco_charity';

    /**
     * Collect fee address amount
     *
     * @param Mage_Sales_Model_Quote_Address $address
     * @return CherryCheckoutCore_Charity_Model_Sales_Quote_Address_Total_Fee
     */
    public function collect(Mage_Sales_Model_Quote_Address $address)
    {
        parent::collect($address);
        $this->_setAmount(0);
        $this->_setBaseAmount(0);
        $items = $this->_getAddressItems($address);
        if (!count($items)) {
            return $this;
        }
        if (CherryCheckoutCore_Charity_Model_Total::canApply($address)) {
            $helper = Mage::helper('cco_charity/config');
            $quote = $address->getQuote();
            $grandTotal     = $address->getGrandTotal();
            $baseGrandTotal = $address->getBaseGrandTotal();
    
            $store      = $quote->getStore();
            $totals     = array_sum($address->getAllTotalAmounts());
            $totals     = $store->roundPrice($totals);
            $baseTotals = array_sum($address->getAllBaseTotalAmounts());
            $baseTotals = $store->roundPrice($baseTotals);
            
            $grandTotal     +=  $totals;
            $baseGrandTotal +=  $baseTotals;
            if(($cco_charity_amount_value = $quote->getData('cco_charity_amount_value')) > 0){
                $balance = $cco_charity_amount_value;
                $baseBalance = $cco_charity_amount_value;    
            }
            else{
                $balance = $helper->getPrice($grandTotal);
                $baseBalance = $helper->getPrice($baseGrandTotal);    
            }
            
            $helper->_log("Setting $balance amount for quote ID " . $quote->getId());
            $address->setCcoCharityAmount($balance);
            $address->setBaseCcoCharityAmount($baseBalance);
            $address->setGrandTotal($address->getGrandTotal() + $address->getCcoCharityAmount());
            $address->setBaseGrandTotal($address->getBaseGrandTotal() + $address->getBaseCcoCharityAmount());
        }

        return $this;
    }

    /**
     * Add fee information to address
     *
     * @param Mage_Sales_Model_Quote_Address $address
     * @return CherryCheckoutCore_Charity_Model_Sales_Quote_Address_Total_Fee
     */
    public function fetch(Mage_Sales_Model_Quote_Address $address)
    {
        $_helper = Mage::helper('cco_charity');
        $type = $address->getQuote()->getData('cco_charity_type');
        $name = $address->getQuote()->getData('cco_charity_name');
        $title = $_helper->__($_helper->getLabelType($type));
        
        
        
        $amount = $address->getCcoCharityAmount();
        $address->addTotal(array(
            'code' => $this->getCode(),
            'title' => $title,
            'value' => $amount
        ));
        return $this;
    }

}