<?php

/**
 * 	CHERRY CHECKOUT - PHP SDK
 * 	CherryCheckout\Me
 *
 * 	author:			Alex Potot
 * 	last update:	2017-08-08
 * 	copyright:		Cherry Checkout SA
 * 	website:		https://www.cherrycheckout.com
 * 	support:		support@cherrycheckout.com
 * 	doc:			https://developers.cherrycheckout.com/en/sdk/php
 */

namespace CherryCheckout;

use CherryCheckout\Contract;

class Me
{
	public $contract;
	public $pdfContractLink;
	public $pdfTermsAndConditionsLink;
	public $plugin;
	public $pluginIntegration;

	/**
	 * Me constructor.
	 * @param mixed $apiMe
	 * 	The me object got from api
	 */
	public function __construct($apiMe)
	{
		$this->contract = new Contract($apiMe->contract);
		$this->pdfContractLink = $apiMe->pdfContractLink;
		$this->pdfTermsAndConditionsLink = $apiMe->pdfTermsAndConditionsLink;
		$this->plugin = $apiMe->plugin;
		$this->pluginIntegration = $apiMe->pluginIntegration;
	}

	/**
	 * @return \CherryCheckout\Contract
	 */
	public function getContract()
	{
		return $this->contract;
	}

	/**
	 * Return the link to the your contract pdf file.
	 * @return string
	 */
	public function getPdfContractLink()
	{
		return $this->pdfContractLink;
	}

	/**
	 * Return the link to your terms and conditions pdf file
	 * @return string
	 */
	public function getPdfTermsAndConditionsLink()
	{
		return $this->pdfTermsAndConditionsLink;
	}

	/**
	 * (optional) @param string|bool $lang
	 * 	The language in which you want to display the plugin
	 * @return mixed
	 */
	public function getPlugin($lang = false)
	{
		if (!$lang) {
			return $this->plugin;
		}

		$plugin = (array)$this->plugin;

		if (isset($lang) && isset($plugin[$lang])) {
			return $plugin[$lang];
		}
		else {
			return $plugin['en'];
		}
	}

	public function getPluginIntegration()
	{
		return $this->pluginIntegration;
	}
}