<?php

/**
 * 	CHERRY CHECKOUT - PHP SDK
 * 	CherryCheckout\Order
 *
 * 	author:			Alex Potot
 * 	last update:	2017-08-08
 * 	copyright:		Cherry Checkout SA
 * 	website:		https://www.cherrycheckout.com
 * 	support:		support@cherrycheckout.com
 * 	doc:			https://developers.cherrycheckout.com/en/sdk/php
 */

namespace CherryCheckout;

use CherryCheckout\Customer;

class Order
{
	public $charity;
	public $cherryPrice;
	public $currency;
	public $customer;
	public $orderPrice;
	public $status;
	public $trackId;

	/**
	 * @return string
	 */
	public function getCharity()
	{
		return $this->charity;
	}

	/**
	 * @param string $charity
	 * 	The charity id you want to make the donate
	 * @return $this
	 */
	public function setCharity($charity)
	{
		$this->charity = $charity;
		return $this;
	}

	/**
	 * @return int
	 */
	public function getCherryPrice()
	{
		return $this->cherryPrice;
	}

	/**
	 * @param int $cherryPrice
	 * 	The number of cherries added to cart
	 * @return $this
	 */
	public function setCherryPrice($cherryPrice)
	{
		$this->cherryPrice = $cherryPrice;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getCurrency()
	{
		return $this->currency;
	}

	/**
	 * @param string $currency
	 * 	The currency of order (eur|chf)
	 * @return $this
	 */
	public function setCurrency($currency)
	{
		$this->currency = $currency;
		return $this;
	}

	/**
	 * @return Customer
	 */
	public function getCustomer()
	{
		return $this->customer;
	}

	/**
	 * @param Customer $customer
	 * 	Some data about the customer of the order
	 * @return $this
	 */
	public function setCustomer(Customer $customer)
	{
		$this->customer = $customer;
		return $this;
	}

	/**
	 * @return float
	 */
	public function getOrderPrice()
	{
		return $this->orderPrice;
	}

	/**
	 * @param float $orderPrice
	 * 	The total order price (cherry price excluded)
	 * @return $this
	 */
	public function setOrderPrice($orderPrice)
	{
		$this->orderPrice = $orderPrice;
		return $this;
	}

	/**
	 * @return string
	 */
	public function getStatus()
	{
		return $this->status;
	}

	/**
	 * @param string $status
	 *  The status of the order (validated|canceled)
	 * @return $this
	 */
	public function setStatus($status)
	{
		if ($status == 'canceled') {
			$this->status = $status;
		}
		else {
			$this->status = 'validated';
		}

		return $this;
	}

	/**
	 * @return string
	 */
	public function getTrackId()
	{
		return $this->trackId;
	}

	/**
	 * @param string $trackId
	 *  The id of the order. Must be unique for each order
	 * @return $this
	 */
	public function setTrackId($trackId)
	{
		$this->trackId = $trackId;
		return $this;
	}
}